pub struct Size { /* private fields */ }Expand description
Represents the size (width and height) of an image.
Implementations
Sourceimpl Size
impl Size
Sourcepub const fn new(width: u32, height: u32) -> Self
pub const fn new(width: u32, height: u32) -> Self
Creates a new Size with the given width and height.
Arguments
width- The width of the image in pixels.height- The height of the image in pixels.
Sourcepub const fn square(size: u32) -> Self
pub const fn square(size: u32) -> Self
Creates a new Size with equal width and height (a square).
Arguments
size- The width and height of the square image in pixels.
Sourcepub const fn pixel_count(&self) -> u64
pub const fn pixel_count(&self) -> u64
Returns the total number of pixels (width × height).