SupportedParameters

Struct SupportedParameters 

#[non_exhaustive]
pub struct SupportedParameters { pub max_tokens: bool, pub temperature: bool, pub top_p: bool, pub reasoning: bool, pub include_reasoning: bool, pub structured_outputs: bool, pub response_format: bool, pub stop: bool, pub frequency_penalty: bool, pub presence_penalty: bool, pub seed: bool, }
Indicates which parameters are supported by a model.

This struct is used to communicate which configuration parameters a specific model supports, allowing applications to adjust their requests accordingly.

Examples

use aither::llm::model::SupportedParameters;

let mut support = SupportedParameters::default();

support.temperature = true;
support.max_tokens = true;
support.top_p = true;
support.stop = true;
support.seed = true;

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
max_tokens: bool

Whether max_tokens is supported.

temperature: bool

Whether temperature is supported.

top_p: bool

Whether top_p is supported.

reasoning: bool

Whether reasoning is supported.

include_reasoning: bool

Whether including reasoning is supported.

structured_outputs: bool

Whether structured outputs are supported.

response_format: bool

Whether response format is supported.

stop: bool

Whether stop sequences are supported.

frequency_penalty: bool

Whether frequency penalty is supported.

presence_penalty: bool

Whether presence penalty is supported.

seed: bool

Whether seed is supported.