Text-to-image generation.
Contains ImageGenerator trait for creating images from text.
Structs
- Prompt
- Represents a prompt for image generation, including text and optional images.
- Size
- Represents the size (width and height) of an image.
Traits
- Image
Generator - Trait for generating and editing images from prompts and masks.
Type Aliases
- Data
- Image data as bytes.