Enum Ability Copy item path Source #[non_exhaustive]
pub enum Ability {
Show 13 variants ToolUse,
Vision,
Audio,
AudioOutput,
Video,
WebSearch,
Pdf,
CodeExecution,
Reasoning,
ImageGeneration,
ComputerUse,
PromptCaching,
AssistantPrefill,
}Expand description Represents the capabilities that a language model may support.
This enum defines the various advanced capabilities that modern language
models can possess beyond basic text generation. These capabilities can
be used to determine which models are suitable for specific use cases.
 Examples
ⓘ use aither::llm::model::Ability;
let abilities = [Ability::Vision, Ability::ToolUse];
let has_vision = abilities.contains(& Ability::Vision);This enum is marked as non-exhaustive Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
The model can use external tools/functions.
The model can process and understand images.
The model can process and understand audio.
The model can generate audio output.
The model can process and understand video.
The model can perform web searches natively.
The model can directly read and reason over PDF or document attachments.
The model can execute code.
The model supports extended thinking/reasoning.
The model can generate images.
The model supports computer use / desktop interaction.
The model supports prompt caching.
The model supports assistant prefill (pre-filling assistant responses).
Performs copy-assignment from
source.
Read more Formats the value using the given formatter.
Read more Deserialize this value from the given Serde deserializer.
Read more Compares and returns the maximum of two values.
Read more Compares and returns the minimum of two values.
Read more Restrict a value to a certain interval.
Read more 🔬 This is a nightly-only experimental API. (clamp_to)
Restrict a value to a certain range.
Read more This method returns an ordering between
self and
other values if one exists.
Read more Tests less than (for
self and
other) and is used by the
< operator.
Read more Tests less than or equal to (for
self and
other) and is used by the
<= operator.
Read more Tests greater than (for
self and
other) and is used by the
>
operator.
Read more Tests greater than or equal to (for
self and
other) and is used by
the
>= operator.
Read more Serialize this value into the given Serde serializer.
Read more Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more 🔬 This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From <T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more Uses borrowed data to replace owned data, usually by cloning.
Read more The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.