#[non_exhaustive]pub struct SupportedParameters {
pub max_tokens: bool,
pub temperature: bool,
pub top_p: bool,
pub reasoning: bool,
pub include_reasoning: bool,
pub structured_outputs: bool,
pub response_format: bool,
pub stop: bool,
pub frequency_penalty: bool,
pub presence_penalty: bool,
pub seed: bool,
}Expand description
Indicates which parameters are supported by a model.
This struct is used to communicate which configuration parameters a specific model supports, allowing applications to adjust their requests accordingly.
Examples
ⓘ
use aither::llm::model::SupportedParameters;
let mut support = SupportedParameters::default();
support.temperature = true;
support.max_tokens = true;
support.top_p = true;
support.stop = true;
support.seed = true;Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.max_tokens: boolWhether max_tokens is supported.
temperature: boolWhether temperature is supported.
top_p: boolWhether top_p is supported.
reasoning: boolWhether reasoning is supported.
include_reasoning: boolWhether including reasoning is supported.
structured_outputs: boolWhether structured outputs are supported.
response_format: boolWhether response format is supported.
stop: boolWhether stop sequences are supported.
frequency_penalty: boolWhether frequency penalty is supported.
presence_penalty: boolWhether presence penalty is supported.
seed: boolWhether seed is supported.